@@ -6,7 +6,7 @@ from PySide.QtGui import *
 from PySide.QtMaemo5 import QMaemo5ValueButton, QMaemo5ListPickSelector
 
 # Some global variables
-Cps2GuiVersion = "0.0.1-2"
+Cps2GuiVersion = "0.0.1-3"
 CommentChar = '#'
 OptionChar =  ' '
 Home = os.path.expanduser("~")
@@ -160,8 +160,7 @@ class Ui_MainWindow(QMainWindow):
 	# but first, re-read all settings
         self.gui_opts = parse_config(self,Cps2Gui_CfgFile)
         if self.onesmutePushButton.isChecked():
-		ALL_OPTS="--sound "
-		#ALL_OPTS="--no-sound "  <--should be this
+		ALL_OPTS="--sound " # should be --no-sound
         else:  ALL_OPTS="--sound "
         if self.gui_opts["showfps"] == "false":
 		ALL_OPTS = ALL_OPTS + "--no-showfps "
@@ -387,7 +386,6 @@ class ConfigWindow(QMainWindow):
 		else:
 			newConfigFile.write("# Generated by cps2-gui\n")
 			for option in self.gui_opts:
-				print self.gui_opts[option]
 				newConfigFile.write(option + " " + self.gui_opts[option] + "\n")
 			newConfigFile.close()
 			os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
@@ -1187,8 +1185,48 @@ class pathWindow(QDialog):
 	self.close()
 
     def on_rom_button_clicked(self):
+	d = QDialog(self)
+ 
+	vbox = QVBoxLayout()
+	#Add Layouts
+	horizontalLayout = QHBoxLayout() 
+
+	# Now create your buttons.
+	homeButton = QPushButton("internal")
+	rootButton = QPushButton("SD card")
+	closeButton = QPushButton("Close")
+	# Add buttons to your layouts, they'll show up in the order given.
+	horizontalLayout.addWidget(homeButton)
+	horizontalLayout.addWidget(rootButton)
+	horizontalLayout.addWidget(closeButton)
+	# Add layouts to your main Layout
+	vbox.addLayout (horizontalLayout)
+	d.setLayout(vbox)
+        d.setWindowTitle("Choose roms location...")
+ 
+	# Show the window!
+	d.show()
+	QObject.connect(homeButton
+		, SIGNAL("clicked()")
+		, self.on_rom_homebutton_clicked)
+	QObject.connect(rootButton
+		, SIGNAL("clicked()")
+		, self.on_rom_rootbutton_clicked)
+	QObject.connect(closeButton
+		, SIGNAL("clicked()")
+		, d.close)
+
+    def on_rom_homebutton_clicked(self):
 	global RomPath
-	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/home')
+	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/home', QFileDialog.ShowDirsOnly)
+	self.close()
+	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
+	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
+	           string:"Use SAVE button to save it!"')
+
+    def on_rom_rootbutton_clicked(self):
+	global RomPath
+	RomPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/media', QFileDialog.ShowDirsOnly)
 	self.close()
 	os.system('run-standalone.sh dbus-send --type=method_call --dest=org.freedesktop.Notifications  \
 	           /org/freedesktop/Notifications org.freedesktop.Notifications.SystemNoteInfoprint \
@@ -1197,8 +1235,8 @@ class pathWindow(QDialog):
     def on_exec_button_clicked(self):
 	global ExecPath
 	ExecPath = QFileDialog.getExistingDirectory(self, 'Choose directory', '/home/')
-	if (not os.path.isfile(ExecPath + "/cps2")) and (ExecPath != "") :
-		QMessageBox.critical(self, "Warning",  "Cannot find " + ExecPath + "/cps2")
+	if (not os.path.isfile(ExecPath + "/cps2emu")) and (ExecPath != "") :
+		QMessageBox.critical(self, "Warning",  "Cannot find " + ExecPath + "/cps2emu")
 	self.close()
 
 if __name__ == "__main__":
